@@ -1,38 +1,48 @@
-from typing import List, Tuple
-
 from hdx.location.adminlevel import AdminLevel
 
 
 def complete_admins(
-    admins: List[AdminLevel],
+    admins: list[AdminLevel],
     countryiso3: str,
-    provider_adm_names: List,
-    adm_codes: List,
-    adm_names: List,
+    provider_adm_names: list,
+    adm_codes: list,
+    adm_names: list,
     fuzzy_match: bool = True,
-) -> Tuple[int, List[str]]:
+) -> tuple[int, list[str]]:
     """Use information from adm_codes to populate adm_names and from
     provider_adm_names to populate adm_codes with outptu of the admin level
     and arnings for unknown and mismatched p-codes. All provided lists
     should be of the same length.
 
     Args:
-        admins (List[AdminLevel]): List of AdminLevel objects
-        countryiso3 (str): Country ISO3 code
-        provider_adm_names (List): List of provider adm names
-        adm_codes (List): List of adm codes
-        adm_names (List): List of adm names
-        fuzzy_match (bool): Whether to use fuzzy matching. Default is True.
+        admins: List of AdminLevel objects
+        countryiso3: Country ISO3 code
+        provider_adm_names: List of provider adm names
+        adm_codes: List of adm codes
+        adm_names: List of adm names
+        fuzzy_match: Whether to use fuzzy matching. Default is True.
 
     Returns:
-        Tuple[int, List[str]]: Admin level and warnings
+        Admin level and warnings
     """
 
     warnings = []
     child = None
     adm_level = len(provider_adm_names)
+
+    def check_unknown_pcode(adm_code: str, pcode: str) -> str:
+        if pcode:
+            warnings.append(f"PCode unknown {adm_code}->{pcode} ({warntxt})")
+            return pcode
+        else:
+            warnings.append(f"PCode unknown {adm_code}->''")
+            return ""
+
     for i, provider_adm_name in reversed(list(enumerate(provider_adm_names))):
         adm_code = adm_codes[i]
+        parent = admins[i].pcode_to_parent.get(adm_code)
+        if not parent and i > 0:
+            parent = adm_codes[i - 1]
         if not provider_adm_name:
             provider_adm_name = ""
             provider_adm_names[i] = ""
@@ -40,9 +50,6 @@ def complete_admins(
             pcode = admins[i + 1].pcode_to_parent.get(child)
             warntxt = "parent"
         elif provider_adm_name:
-            parent = admins[i].pcode_to_parent.get(adm_code)
-            if not parent and i > 0:
-                parent = adm_codes[i - 1]
             pcode, _ = admins[i].get_pcode(
                 countryiso3,
                 provider_adm_name,
@@ -54,24 +61,23 @@ def complete_admins(
             pcode = None
         if adm_code:
             if adm_code not in admins[i].pcodes:
-                if pcode:
-                    warnings.append(
-                        f"PCode unknown {adm_code}->{pcode} ({warntxt})"
+                if admins[i].looks_like_pcode(adm_code):
+                    adj_adm_code = admins[i].convert_admin_pcode_length(
+                        countryiso3, adm_code, parent=parent
                     )
-                    adm_code = pcode
+                    if adj_adm_code:
+                        warnings.append(f"PCode length {adm_code}->{adj_adm_code}")
+                        adm_code = adj_adm_code
+                    else:
+                        adm_code = check_unknown_pcode(adm_code, pcode)
                 else:
-                    warnings.append(f"PCode unknown {adm_code}->''")
-                    adm_code = ""
+                    adm_code = check_unknown_pcode(adm_code, pcode)
             elif pcode and adm_code != pcode:
                 if child:
-                    warnings.append(
-                        f"PCode mismatch {adm_code}->{pcode} ({warntxt})"
-                    )
+                    warnings.append(f"PCode mismatch {adm_code}->{pcode} ({warntxt})")
                     adm_code = pcode
                 else:
-                    warnings.append(
-                        f"PCode mismatch {adm_code} != {provider_adm_name}"
-                    )
+                    warnings.append(f"PCode mismatch {adm_code} != {provider_adm_name}")
         elif pcode:
             adm_code = pcode
         else:
@@ -88,21 +94,21 @@ def complete_admins(
 
 
 def pad_admins(
-    provider_adm_names: List[str],
-    adm_codes: List[str],
-    adm_names: List[str],
+    provider_adm_names: list[str],
+    adm_codes: list[str],
+    adm_names: list[str],
     adm_level: int = 2,
 ) -> None:
     """Pad lists to size given in adm_level adding as many "" as needed.
 
     Args:
-        provider_adm_names (List): List of provider adm names
-        adm_codes (List): List of adm codes
-        adm_names (List): List of adm names
-        adm_level (int): Admin level to which to pad. Default is 2.
+        provider_adm_names: List of provider adm names
+        adm_codes: List of adm codes
+        adm_names: List of adm names
+        adm_level: Admin level to which to pad. Default is 2.
 
     Returns:
-        Tuple[int, List[str]]: Admin level and warnings
+        Admin level and warnings
     """
 
     for i in range(len(provider_adm_names), adm_level):
