@@ -6,9 +6,7 @@ class TestLookup:
     def test_sector(self, configuration):
         sector = Sector()
         assert sector.get_code("child protection") == "PRO-CPN"
-        assert (
-            sector.get_code("gestion des sites daccueil temporaires") == "SHL"
-        )
+        assert sector.get_code("gestion des sites daccueil temporaires") == "SHL"
         assert "Intersectoral" in sector.get_code_to_name()
         assert sector.get_name("PRO-MIN") == "Mine Action"
         assert sector.get_name("xxx") is None
